/*
 * $Id$
 *
 * [ Description ]
 * 
 */

#include "Behavioural/Generic/Counter/include/Parameters.h"
#include "Behavioural/include/XML.h"
using namespace std;

namespace morpheo                    {
namespace behavioural {
namespace generic {
namespace counter {


  string Parameters::print (uint32_t depth)
  {
    log_printf(FUNC,Counter,"print","Begin");

    XML xml ("counter");

    xml.balise_open("counter");
    xml.  singleton_begin("size_data");
    xml.    attribut("value",toString(_size_data));
    xml.  singleton_end();
    xml.  singleton_begin("nb_port  ");
    xml.    attribut("value",toString(_nb_port));
    xml.  singleton_end();
    xml.balise_close();

    log_printf(FUNC,Counter,"print","End");
    
    return xml.get_body(depth);
  };

  ostream& operator<< (ostream& output_stream ,
		       morpheo::behavioural::generic::counter::Parameters & x)
  {
    output_stream << x.print(0);
    
    return output_stream;
  };

}; // end namespace counter
}; // end namespace generic

}; // end namespace behavioural
}; // end namespace morpheo              
